@@ -10,6 +10,7 @@ import logging
 import os
 import sys
 from abc import ABC, abstractmethod
+from enum import IntEnum
 from os import PathLike, path
 from tempfile import NamedTemporaryFile
 from typing import ContextManager, TextIO
@@ -17,6 +18,7 @@ from typing import ContextManager, TextIO
 import argcomplete
 import questionary
 from argcomplete.completers import FilesCompleter
+from packaging.version import Version
 
 from pybricksdev import __name__ as MODULE_NAME
 from pybricksdev import __version__ as MODULE_VERSION
@@ -113,6 +115,11 @@ class Compile(Tool):
             choices=[5, 6],
             type=int,
         )
+        parser.add_argument(
+            "--bin",
+            action="store_true",
+            help="output unformatted binary data only (useful for pipes)",
+        )
         parser.tool = self
 
     async def run(self, args: argparse.Namespace):
@@ -120,6 +127,9 @@ class Compile(Tool):
 
         with _get_script_path(args.file) as script_path:
             mpy = await compile_multi_file(script_path, args.abi)
+        if args.bin:
+            sys.stdout.buffer.write(mpy)
+            return
         print_mpy(mpy)
 
 
@@ -239,6 +249,13 @@ class Run(Tool):
             if not args.stay_connected:
                 return
 
+            class ResponseOptions(IntEnum):
+                RECOMPILE_RUN = 0
+                RECOMPILE_DOWNLOAD = 1
+                RUN_STORED = 2
+                CHANGE_TARGET_FILE = 3
+                EXIT = 4
+
             async def reconnect_hub():
                 if not await questionary.confirm(
                     "\nThe hub has been disconnected. Would you like to re-connect?"
@@ -264,8 +281,19 @@ class Run(Tool):
             response_options = [
                 "Recompile and Run",
                 "Recompile and Download",
+                "Run Stored Program",
+                "Change Target File",
                 "Exit",
             ]
+            # the entry that is selected by default when the menu opens
+            # this is overridden after the user picks an option
+            # so that the default option is always the one that was last chosen
+            default_response_option = (
+                ResponseOptions.RECOMPILE_RUN
+                if args.start
+                else ResponseOptions.RECOMPILE_DOWNLOAD
+            )
+
             while True:
                 try:
                     if args.file is sys.stdin:
@@ -280,22 +308,55 @@ class Run(Tool):
                     response = await hub.race_disconnect(
                         hub.race_power_button_press(
                             questionary.select(
-                                "Would you like to re-compile your code?",
+                                f"Would you like to re-compile {os.path.basename(args.file.name)}?",
                                 response_options,
-                                default=(
-                                    response_options[0]
-                                    if args.start
-                                    else response_options[1]
-                                ),
+                                default=(response_options[default_response_option]),
                             ).ask_async()
                         )
                     )
-                    with _get_script_path(args.file) as script_path:
-                        if response == response_options[0]:
-                            await hub.run(script_path, wait=True)
-                        elif response == response_options[1]:
-                            await hub.download(script_path)
-                        else:
+
+                    default_response_option = response_options.index(response)
+
+                    match response_options.index(response):
+
+                        case ResponseOptions.RECOMPILE_RUN:
+                            with _get_script_path(args.file) as script_path:
+                                await hub.run(script_path, wait=True)
+
+                        case ResponseOptions.RECOMPILE_DOWNLOAD:
+                            with _get_script_path(args.file) as script_path:
+                                await hub.download(script_path)
+
+                        case ResponseOptions.RUN_STORED:
+                            if hub.fw_version < Version("3.2.0-beta.4"):
+                                print(
+                                    "Running a stored program remotely is only supported in the hub firmware version >= v3.2.0."
+                                )
+                            else:
+                                await hub.start_user_program()
+                                await hub._wait_for_user_program_stop()
+
+                        case ResponseOptions.CHANGE_TARGET_FILE:
+                            args.file.close()
+                            while True:
+                                try:
+                                    args.file = open(
+                                        await hub.race_disconnect(
+                                            hub.race_power_button_press(
+                                                questionary.path(
+                                                    "What file would you like to use?"
+                                                ).ask_async()
+                                            )
+                                        )
+                                    )
+                                    break
+                                except FileNotFoundError:
+                                    print("The file was not found. Please try again.")
+                            # send the new target file to the hub
+                            with _get_script_path(args.file) as script_path:
+                                await hub.download(script_path)
+
+                        case _:
                             return
 
                 except HubPowerButtonPressedError:
